databasesql

package module
v0.0.0-...-bd409fd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2026 License: Apache-2.0 Imports: 18 Imported by: 0

Documentation

Overview

Copyright (c) 2025 Alibaba Group Holding Ltd.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildDatabaseSqlOtelInstrumenter

func BuildDatabaseSqlOtelInstrumenter() instrumenter.Instrumenter[databaseSqlRequest, any]

Types

type SQLMeta

type SQLMeta struct {
	// contains filtered or unexported fields
}

type SQLMetaCache

type SQLMetaCache struct {
	// contains filtered or unexported fields
}

func NewSQLMetaCache

func NewSQLMetaCache(size int) (*SQLMetaCache, error)

func (*SQLMetaCache) Add

func (c *SQLMetaCache) Add(key string, value SQLMeta) bool

func (*SQLMetaCache) Contains

func (c *SQLMetaCache) Contains(key string) bool

func (*SQLMetaCache) Get

func (c *SQLMetaCache) Get(key string) (SQLMeta, bool)

func (*SQLMetaCache) Len

func (c *SQLMetaCache) Len() int

func (*SQLMetaCache) Remove

func (c *SQLMetaCache) Remove(key string) bool

Jump to