Documentation
¶
Index ¶
- func Assert(cond bool, format string, args ...interface{})
- func DeepCopyMetric(mrs metricdata.ResourceMetrics) metricdata.ResourceMetrics
- func GetAttribute(attrs []attribute.KeyValue, name string) attribute.Value
- func GetAttributesWithPrefix(attrs []attribute.KeyValue, prefix string) []string
- func GetFreePort() (int, error)
- func GetServer(ctx context.Context, url string) (string, error)
- func SliceAttrsAssert(expectAttrs []any, actualAttrs []string, format string, args ...interface{})
- func VerifyDbAttributes(span tracetest.SpanStub, ...)
- func VerifyDbMetricsAttributes(attrs []attribute.KeyValue, dbSystem, operationName, serverAddress string)
- func VerifyGenAIOperationDurationMetricsAttributes(attrs []attribute.KeyValue, ...)
- func VerifyHttpClientAttributes(span tracetest.SpanStub, ...)
- func VerifyHttpClientMetricsAttributes(attrs []attribute.KeyValue, ...)
- func VerifyHttpServerAttributes(span tracetest.SpanStub, ...)
- func VerifyHttpServerMetricsAttributes(attrs []attribute.KeyValue, ...)
- func VerifyK8sPodEventAttributes(span tracetest.SpanStub, ...)
- func VerifyLLMAttributes(span tracetest.SpanStub, name string, system string, model string)
- func VerifyLLMAttributesWithGenAISpanKind(span tracetest.SpanStub, name string, system string, model string, ...)
- func VerifyLLMCommonAttributes(span tracetest.SpanStub, name string, system string, spanKind trace.SpanKind)
- func VerifyLLMCommonAttributesWithGenAISpanKind(span tracetest.SpanStub, name string, system string, spanKind trace.SpanKind, ...)
- func VerifyMQConsumeAttributes(span tracetest.SpanStub, ...)
- func VerifyMQPublishAttributes(span tracetest.SpanStub, ...)
- func VerifyMQTTMessageBodySize(span tracetest.SpanStub, minSize int64)
- func VerifyMQTTPublishAttributes(span tracetest.SpanStub, topic string, qos byte, expectedError bool)
- func VerifyMQTTReceiveAttributes(span tracetest.SpanStub, topic string, expectedError bool)
- func VerifyMQTTSubscribeAttributes(span tracetest.SpanStub, topic string, qos byte, expectedError bool)
- func VerifyMQTTTraceContext(publisher tracetest.SpanStub, subscriber tracetest.SpanStub)
- func VerifyRpcClientAttributes(span tracetest.SpanStub, name, system, service, method string)
- func VerifyRpcClientMetricsAttributes(attrs []attribute.KeyValue, method, service, system, serverAddr string)
- func VerifyRpcServerAttributes(span tracetest.SpanStub, name, system, service, method string)
- func VerifyRpcServerMetricsAttributes(attrs []attribute.KeyValue, method, service, system, serverAddr string)
- func VerifySentinelAttributes(span tracetest.SpanStub, resourceName, EntryType, BlockType string, ...)
- func WaitAndAssertMetrics(metricVerifiers map[string]func(metricdata.ResourceMetrics))
- func WaitAndAssertTraces(traceVerifiers func([]tracetest.SpanStubs), numTraces int)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeepCopyMetric ¶
func DeepCopyMetric(mrs metricdata.ResourceMetrics) metricdata.ResourceMetrics
func GetAttributesWithPrefix ¶
Get all attrs with a prefix like `db.query.parameter.0` with `db.query.parameter`
func GetFreePort ¶
func SliceAttrsAssert ¶
Compare two attrs of slice type
func VerifyDbAttributes ¶
func VerifyDbAttributes(span tracetest.SpanStub, name, system, address, statement, operation, collection string, params []any)
VerifyDbAttributes TODO: make attribute name to semconv attribute
func VerifyLLMAttributes ¶
func VerifyMQTTMessageBodySize ¶
VerifyMQTTMessageBodySize verifies message body size attribute
func VerifyMQTTPublishAttributes ¶
func VerifyMQTTPublishAttributes(span tracetest.SpanStub, topic string, qos byte, expectedError bool)
VerifyMQTTPublishAttributes verifies span attributes for MQTT publish operation
func VerifyMQTTReceiveAttributes ¶
VerifyMQTTReceiveAttributes verifies span attributes for MQTT receive/process operation
func VerifyMQTTSubscribeAttributes ¶
func VerifyMQTTSubscribeAttributes(span tracetest.SpanStub, topic string, qos byte, expectedError bool)
VerifyMQTTSubscribeAttributes verifies span attributes for MQTT subscribe operation
func VerifyMQTTTraceContext ¶
VerifyMQTTTraceContext verifies trace context propagation between publisher and subscriber
func WaitAndAssertMetrics ¶
func WaitAndAssertMetrics(metricVerifiers map[string]func(metricdata.ResourceMetrics))
func WaitAndAssertTraces ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.